import numpy as np

def greeting():
    print('Hi, i greeting from Greetings.greeting() module!.')
    
    
def test():
    print('This is a new test of change in the new version 1.4!.')
    
    
def generar_array(numeros):
    return np.arange(numeros)

class Greeting:
    def __init__(self):
        print('Hola, te saludo desde Greeting.__init__')
    

if __name__ == '__main__':
    # greeting()
    print(generar_array(5))


import unittest
from messages.greeting.Greetings import generar_array

from messages.greeting.Greetings import *# greeting, Greeting
from messages.farewell.Farewell import *# farewell, Farewell

class PruebasHola(unittest.TestCase):

    def test_generar_array(self):
        np.testing.assert_array_equal(
            np.array([0, 1, 2, 3, 4, 5]),
            generar_array(6)
        )

greeting()
Greeting()

farewell()
Farewell()


from setuptools import setup, find_packages

setup(
    name ='messages_test_nan',
    version='1.4',
    author='Eduardo Nanduca',
    author_email='acudnan@gmail.com',
    description='Un paquete con los mensajes para saludar y despedirse',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://www.fb.com/acudnan_',
    license='MIT License',
    packages=find_packages(),
    scripts=[],
    test_suite='tests',
    install_requires=[paquete.strip() 
                      for paquete in open("requirements.txt").readlines()],
    classifiers=[
        'Environment :: Console :: Curses',
        'Programming Language :: Python :: 3.13',
        'Topic :: Utilities',
        'Operating System :: Microsoft :: Windows',
    ]
)